tonalanalysistools.RomanNumeral
===============================

.. abjad-lineage:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral

.. autoclass:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.bass_scale_degree
      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.extent
      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.figured_bass_string
      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.inversion
      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.markup
      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.quality
      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.root_scale_degree
      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.scale_degree
      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.suspension
      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.symbolic_string
      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.__eq__
      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.__format__
      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.__hash__
      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.__ne__
      ~abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.bass_scale_degree
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.extent
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.figured_bass_string
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.inversion
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.markup
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.quality
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.root_scale_degree
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.scale_degree
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.suspension
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.symbolic_string
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.__format__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.__hash__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.RomanNumeral.RomanNumeral.__repr__
   :noindex:
